"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const flags = require("@oclif/command/lib/flags");
const path = require("path");
const conf_1 = require("../services/conf");
const docker_1 = require("../services/docker");
const logger_1 = require("../services/logger");
class Index extends command_1.Command {
    constructor() {
        super(...arguments);
        this.verbose = false;
    }
    get mustachesDir() {
        return path.resolve(__dirname, 'mustaches');
    }
    get frameworks() {
        return conf_1.default.frameworks;
    }
    async init() {
        // @ts-ignore
        const { flags } = this.parse(this.constructor);
        this.verbose = flags.verbose;
        await docker_1.default.checkEnv();
        // check user input args here
        const args = await this.preInit();
        // initialize everything needed here
        await this.initialize(args);
        logger_1.logger.info('Preparing');
        // prepare running context here
        await this.preRun();
    }
    async catch(e) {
        if (this.verbose) {
            logger_1.logger.error(e);
        }
        else {
            logger_1.logger.error(e.message);
        }
        this.exit(1);
    }
    async finally(e) {
        if (!e) {
            await this.postRun();
        }
    }
    async preInit() { }
    async initialize(_args) { }
    async preRun() { }
    async postRun() { }
}
Index.flags = {
    verbose: flags.boolean({ char: 'v', required: false, description: 'show verbose logs' }),
};
exports.default = Index;
