"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs = require("fs");
const path = require("path");
const base_1 = require("../base");
const conf_1 = require("../services/conf");
const util_1 = require("../util");
const { resolve } = path;
class RunBase extends base_1.default {
    constructor() {
        super(...arguments);
        this.type = '';
        this.cmd = '';
        this.watch = false;
    }
    async preInit() {
        // @ts-ignore
        const { flags, args } = this.parse(this.constructor);
        this.cmd = args.cmd;
        this.watch = flags.watch;
        return flags;
    }
    async initialize() {
        await util_1.default.asyncExec('rm -rf .tmp && mkdir .tmp');
        const { appConfPath, rdcConfPath, cwd, RdTypes } = conf_1.default;
        if (fs.existsSync(appConfPath)) {
            this.type = RdTypes.Application;
        }
        if (fs.existsSync(rdcConfPath)) {
            this.type = RdTypes.Container;
        }
        if (!this.type) {
            throw Error('no rde config file found, please read docs first');
        }
        const appDir = resolve(`${cwd}/app`);
        const templateDir = resolve(`${cwd}/template`);
        if (this.type === 'container' && !fs.existsSync(templateDir)) {
            throw Error('template dir cannot be found in cwd, please provide');
        }
        if (!fs.existsSync(appDir)) {
            throw Error('app dir cannot be found in cwd, please provide');
        }
    }
    async run() { }
}
RunBase.args = [{
        name: 'cmd',
        required: true,
        description: 'scripts provided by container',
    }];
RunBase.flags = Object.assign({}, base_1.default.flags, { watch: command_1.flags.boolean({ char: 'w' }) });
exports.default = RunBase;
