"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const inquirer = require("inquirer");
const base_1 = require("../base");
const application_1 = require("../core/create/application");
const container_1 = require("../core/create/container");
const suite_1 = require("../core/create/suite");
const conf_1 = require("../services/conf");
const logger_1 = require("../services/logger");
const util_1 = require("../util");
class Create extends base_1.default {
    constructor() {
        super(...arguments);
        this.name = '';
        this.type = '';
        this.framework = 'vue';
        this.rdc = '';
        this.rdcRepo = '';
        this.from = '';
    }
    async preInit() {
        const { flags } = this.parse(Create);
        const { from } = flags;
        this.from = from;
        return flags;
    }
    async initialize() {
        await this.ask();
    }
    async preRun() {
        await util_1.default.asyncExec(`mkdir ${this.name}`);
        process.chdir(this.name);
    }
    async run() {
        const opts = {
            name: this.name,
            type: this.type,
            framework: this.framework,
            rdc: this.rdc,
            extendRdc: !!this.from,
            rdcRepo: this.rdcRepo,
        };
        let core = null;
        const { RdTypes } = conf_1.default;
        switch (this.type) {
            case RdTypes.Application:
                core = new application_1.default(opts);
                break;
            case RdTypes.Container:
                core = new container_1.default(opts);
                break;
            case RdTypes.Suite:
                core = new suite_1.default(opts);
        }
        await core.start();
    }
    async postRun() {
        logger_1.logger.star('Run successfully');
        logger_1.logger.star('Hello from RDE, explore with:');
        logger_1.logger.star('$ rde serve');
    }
    async ask() {
        const { RdTypes, frameworks } = conf_1.default;
        this.name = await cli_ux_1.default.prompt('name of project', {
            required: true,
        });
        if (this.from) {
            this.type = 'container';
            this.rdc = this.from;
            return;
        }
        const { type, framework } = await inquirer.prompt([
            {
                name: 'type',
                message: 'what kind of project do you want to create?',
                type: 'list',
                choices: Object.keys(RdTypes).map(name => ({ name })),
                default: RdTypes.Application,
            },
            {
                name: 'framework',
                message: 'what kind of framework do you prefer?',
                type: 'list',
                choices: Object.keys(frameworks).map(name => ({ name })),
                default: 'vue',
            },
        ]);
        if (type === RdTypes.Application) {
            const name = await cli_ux_1.default.prompt('name of container', {
                required: true,
            });
            const version = await cli_ux_1.default.prompt('version of container(latest)', {
                required: false,
                default: 'latest',
            });
            this.rdc = `${name}:${version}`;
        }
        if (type === RdTypes.Container) {
            this.rdcRepo = await cli_ux_1.default.prompt('docker hub repository name', {
                required: true,
            });
            const name = conf_1.default.frameworks[this.framework].rdcStarter;
            this.rdc = `${name}:latest`;
        }
        this.type = type;
        this.framework = framework;
    }
}
Create.description = 'open RDE world';
Create.examples = [
    '$ rde create',
];
Create.flags = Object.assign({}, base_1.default.flags, { from: command_1.flags.string({
        char: 'f',
        description: 'create container from another one',
        parse: input => {
            if (!input.includes(':')) {
                return `${input}:latest`;
            }
            return input;
        },
    }) });
exports.default = Create;
