"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const base_1 = require("../base");
const conf_1 = require("../services/conf");
const docker_1 = require("../services/docker");
const logger_1 = require("../services/logger");
const render_1 = require("../services/render");
const validate_1 = require("../services/validate");
class Publish extends base_1.default {
    async preInit() {
        const { flags } = this.parse(Publish);
        this.tag = flags.tag;
        if (this.tag === 'latest') {
            throw Error('rde will automatic add latest for you, please use semver-like tag');
        }
        await validate_1.validateRdc(true);
        return flags;
    }
    async initialize() {
        const { RdTypes } = conf_1.default;
        await docker_1.default.genDockerFile(RdTypes.Container, this.rdcConf.extends || 'node:latest', conf_1.default.tmpDir);
    }
    async run() {
        const { docker: dockerConf } = this.rdcConf;
        const name = dockerConf.tag.split(':')[0];
        await docker_1.default.tag(`docker tag ${name} ${name}:${this.tag}`);
        await docker_1.default.tag(`docker tag ${name} ${name}:latest`);
        await docker_1.default.push(name);
        this.tag = `${name}:${this.tag}`;
    }
    async postRun() {
        const { docker: dockerConf } = this.rdcConf;
        dockerConf.tag = this.tag;
        await render_1.default.renderTo('module', {
            obj: this.rdcConf,
        }, conf_1.default.rdcConfName, { overwrite: true });
        logger_1.logger.star('Docker tag has been updated successfully');
    }
}
Publish.examples = [
    '$ rde publish',
];
Publish.flags = Object.assign({}, base_1.default.flags, { tag: command_1.flags.string({
        char: 't',
        description: 'as your image tag for pushing to docker hub',
        required: true,
    }) });
exports.default = Publish;
