"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const run_1 = require("../base/run");
const conf_1 = require("../services/conf");
const docker_1 = require("../services/docker");
const logger_1 = require("../services/logger");
const validate_1 = require("../services/validate");
const util_1 = require("../util");
const { RdTypes } = conf_1.default;
class Run extends run_1.default {
    get from() {
        if (this.type === RdTypes.Application) {
            const { app } = conf_1.default.getAppConf();
            return app.container.name;
        }
        if (this.type === RdTypes.Container) {
            const rdcConf = require(`${conf_1.default.cwd}/${conf_1.default.rdcConfName}`);
            return rdcConf.extends || rdcConf.nodeVersion || 'node:latest';
        }
    }
    get tag() {
        if (this.type === RdTypes.Container) {
            const rdcConf = require(`${conf_1.default.cwd}/${conf_1.default.rdcConfName}`);
            return rdcConf.docker.tag || null;
        }
    }
    get ports() {
        if (this.type === RdTypes.Application) {
            const { app } = conf_1.default.getAppConf();
            return app.docker.ports || [];
        }
        if (this.type === RdTypes.Container) {
            const rdcConf = require(`${conf_1.default.cwd}/${conf_1.default.rdcConfName}`);
            return rdcConf.docker.ports || [];
        }
    }
    async preInit() {
        await super.preInit();
        if (this.type === RdTypes.Container) {
            await validate_1.validateRdc();
        }
        if (this.type === RdTypes.Application) {
            await validate_1.validateRda();
        }
    }
    async preRun() {
        await docker_1.default.genDockerFile(this.type, this.from, conf_1.default.tmpDir);
        await docker_1.default.genDockerCompose(this.type, this.from, this.cmd, this.ports, this.watch, this.tag, conf_1.default.tmpDir);
    }
    async run() {
        if (!await docker_1.default.imageExist(this.tag)) {
            logger_1.spinner.start('Building image start');
            await util_1.default.asyncExec(`cd ${conf_1.default.tmpDir} && docker-compose build`);
            logger_1.spinner.stop();
        }
        if (this.watch) {
            await util_1.default.asyncSpawn('docker-compose', ['run', '--rm', 'rde', 'rde', 'docker:run', this.cmd, '--watch'], {
                cwd: conf_1.default.tmpDir,
            });
        }
        else {
            await util_1.default.asyncSpawn('docker-compose', ['run', '--rm', 'rde', 'rde', 'docker:run', this.cmd], {
                cwd: conf_1.default.tmpDir,
            });
        }
    }
}
Run.description = 'run scripts provided by container';
Run.examples = [
    '$ rde run <cmd>',
];
Run.flags = Object.assign({}, run_1.default.flags);
Run.args = [{
        name: 'cmd',
        required: true,
        description: 'scripts provided by container',
    }];
exports.default = Run;
