"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const conf_1 = require("../../services/conf");
const docker_1 = require("../../services/docker");
const render_1 = require("../../services/render");
const util_1 = require("../../util");
const index_1 = require("./index");
class ContainerCreate extends index_1.default {
    async prepare() {
        await docker_1.default.pull(this.rdc);
        const name = this.rdc.split(':')[0];
        if (this.extendRdc) {
            await docker_1.default.copy(this.rdc, `${conf_1.default.workDirRoot}/${name}/app`, `${conf_1.default.cwd}/app`);
            await util_1.default.asyncExec('mkdir template');
        }
        else {
            await docker_1.default.copy(this.rdc, `${conf_1.default.workDirRoot}/${name}/.`, `${conf_1.default.cwd}`);
        }
        await this.getRdcConf();
    }
    async genConfFile() {
        const { rdcConfName, rdcConfPath } = conf_1.default;
        const { docs, framework } = this.rdcConf;
        if (this.extendRdc) {
            await render_1.default.renderTo(`rdc/${rdcConfName.slice(0, -3)}`, {
                extends: this.rdc,
                framework,
                docs: docs ? docs.url : '',
                rdcRepo: this.rdcRepo,
            }, rdcConfName, {
                overwrite: true,
            });
        }
        else {
            const rdcConf = require(rdcConfPath);
            rdcConf.docker.tag = this.rdcRepo;
            await render_1.default.renderTo('module', {
                obj: rdcConf,
            }, rdcConfName, {
                overwrite: true,
            });
        }
    }
    async genExtraFiles() {
        await render_1.default.renderTo('rdc/README', {
            name: this.name,
            homepage: conf_1.default.homepage,
        }, 'README.md', {
            overwrite: true,
        });
        await render_1.default.renderTo('.gitignore', {}, '.gitignore', {
            overwrite: true,
        });
    }
}
exports.default = ContainerCreate;
