"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const extend = require("deep-extend");
const fs = require("fs");
const path = require("path");
const copy = require("recursive-copy");
const conf_1 = require("../services/conf");
const logger_1 = require("../services/logger");
const npm_1 = require("../services/npm");
const render_1 = require("../services/render");
const watcher_1 = require("../services/watcher");
const util_1 = require("../util");
const { resolve } = path;
class DockerRun {
    constructor({ watch }) {
        this.watch = watch;
    }
    async start() {
        logger_1.spinner.start('Preparing Rde Runtime...');
        // generate rdt template from rdt chain
        const config = await this.composeRdcChain();
        // template render to .rde
        await this.renderDir(conf_1.default.tmpDir, config);
        // start watcher
        await this.createRuntime(config);
        logger_1.spinner.stop();
    }
    async composeRdcChain() {
        await util_1.default.asyncExec(`rm -rf ${conf_1.default.tmpDir} && mkdir ${conf_1.default.tmpDir}`);
        const { getRdcChain, getRdcConfFromChain, } = conf_1.default;
        const chain = getRdcChain(conf_1.default.cwd);
        const rdcConf = getRdcConfFromChain(chain);
        let config = rdcConf;
        const rdaConfPath = resolve(conf_1.default.cwd, conf_1.default.appConfName);
        if (fs.existsSync(rdaConfPath)) {
            config = extend(rdcConf, require(rdaConfPath));
        }
        for (let node of chain) {
            let srcDir = resolve(node, 'template');
            await copy(srcDir, resolve(conf_1.default.tmpDir, 'template'), {
                overwrite: true
            });
        }
        await render_1.default.renderTo('module', {
            obj: config
        }, resolve(conf_1.default.tmpDir, conf_1.default.rdcConfName), {
            overwrite: true
        });
        return config;
    }
    async renderDir(dir, config) {
        const srcDir = resolve(dir, 'template');
        // @ts-ignore
        const { render: rdtRender, dev = { render: {} }, container } = config;
        const { includes } = rdtRender;
        const dataView = container.render || dev.render;
        await render_1.default.renderDir(srcDir, Object.assign({}, dataView), includes, conf_1.default.runtimeDir, {
            overwrite: true
        });
        await util_1.default.asyncExec(`rm -rf ${dir}`);
    }
    async createRuntime(config) {
        const { cwd, runtimeDir } = conf_1.default;
        for (let { from, to, option } of config.mappings) {
            const appDir = resolve(cwd, from);
            const destDir = resolve(runtimeDir, to);
            await util_1.default.copy(appDir, destDir, { option });
        }
        await npm_1.default.install('', false, runtimeDir);
        if (this.watch) {
            new watcher_1.default(config.mappings).start();
        }
    }
}
exports.default = DockerRun;
