"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const util_1 = require("../util");
const conf_1 = require("./conf");
const logger_1 = require("./logger");
const render_1 = require("./render");
exports.default = {
    async checkEnv() {
        await util_1.default.asyncExec('docker -v');
        await util_1.default.asyncExec('docker-compose -v');
        // whether is running or not
        await util_1.default.asyncExec('docker info');
    },
    async pull(image) {
        logger_1.spinner.start(`Pulling ${image} from docker...`);
        await util_1.default.asyncExec(`docker pull ${image}`);
        logger_1.spinner.stop();
    },
    async copy(image, from, to) {
        logger_1.spinner.start(`Copy files from ${image}...`);
        if (await this.containerExist('rde-dummy')) {
            await util_1.default.asyncExec('docker container rm /rde-dummy');
        }
        await util_1.default.asyncExec(`docker create -it --name rde-dummy ${image} bash`);
        await util_1.default.asyncExec(`docker cp rde-dummy:${from} ${to}`);
        await util_1.default.asyncExec('docker rm -fv rde-dummy');
        logger_1.spinner.stop();
    },
    async imageExist(name) {
        try {
            await util_1.default.asyncExec(`docker inspect --type=image ${name}`);
            return true;
        }
        catch (e) {
            if (e) { }
            return false;
        }
    },
    async containerExist(name) {
        try {
            await util_1.default.asyncExec(`docker ps -a | grep ${name}`);
            return true;
        }
        catch (e) {
            if (e) { }
            return false;
        }
    },
    async tag(name) {
        await util_1.default.asyncExec(`docker tag -a | grep ${name}`);
    },
    async push(name) {
        await util_1.default.asyncExec(`docker push ${name}`);
    },
    async genDockerFile(type, from, dir) {
        // gen dockerfile
        await render_1.default.renderTo('docker/.dockerignore', {}, `${dir}/.dockerignore`);
        const workDir = conf_1.default.getWorkDir(type, from);
        await render_1.default.renderTo('docker/Dockerfile', {
            from,
            workDir,
        }, `${dir}/Dockerfile`);
    },
    async genDockerCompose(type, from, cmd, ports, watch, tag, dir) {
        const workDir = conf_1.default.getWorkDir(type, from);
        if (!tag) {
            const name = path.basename(conf_1.default.cwd);
            tag = `${name}:latest`;
        }
        await render_1.default.renderTo('docker/docker-compose', {
            workDir,
            cmd,
            ports,
            watch,
            tag,
        }, `${dir}/docker-compose.yml`);
    }
};
