"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
const logger_1 = require("./logger");
exports.default = {
    async install(pkg, isDevDep = true, dir = process.cwd()) {
        logger_1.spinner.start('Installing packages. This might take a while...');
        try {
            if (pkg) {
                await util_1.default.asyncExec(`cd ${dir} && npm i ${isDevDep ? '-D' : ''} ${pkg}`);
            }
            else {
                await util_1.default.asyncExec(`cd ${dir} && npm i`);
            }
            logger_1.logger.info(`Installed package ${pkg}`);
        }
        catch (e) {
            logger_1.logger.error(`Failed to install package ${pkg}: ${e}`);
        }
        finally {
            logger_1.spinner.stop();
        }
    },
    async getInfo(pkg) {
        try {
            const { stdout } = await util_1.default.asyncExec(`npm view ${pkg} -json`);
            return JSON.parse(stdout);
        }
        catch (e) {
            if (e) {
                // logger.error(e)
            }
            return null;
        }
    }
};
