"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const conf_1 = require("./conf");
const message_1 = require("./message");
const { resolve } = path;
exports.validateRda = (useStrict = false) => {
    return useStrict;
};
exports.validateRdc = (useStrict = false) => {
    const { cwd, rdcConfPath, frameworks, } = conf_1.default;
    if (!fs.existsSync(rdcConfPath)) {
        throw Error(message_1.MRDC.UNRECOGNIZED);
    }
    const appDir = resolve(cwd, 'app');
    const tplDir = resolve(cwd, 'template');
    if (!fs.existsSync(appDir)) {
        throw Error(message_1.MRDC.WRONG_DIR_STRUCTURE_APP);
    }
    if (!fs.existsSync(tplDir)) {
        throw Error(message_1.MRDC.WRONG_DIR_STRUCTURE_TPL);
    }
    const rdcConf = require(rdcConfPath);
    this.rdcConf = rdcConf;
    if (!rdcConf.framework ||
        !Object.keys(frameworks).includes(rdcConf.framework)) {
        throw Error(message_1.MCOMMON.WRONG_FRAMEWORK_CONFIG);
    }
    const { docker, mappings, docs } = rdcConf;
    if (!docker || !docker.ports || !docker.ports.length) {
        throw Error(message_1.MCOMMON.WRONG_DOCKER_CONFIG_PORTS);
    }
    if (useStrict && !docker.tag) {
        throw Error(message_1.MCOMMON.WRONG_DOCKER_CONFIG_TAG);
    }
    if (!mappings || !mappings.length) {
        throw Error(message_1.MCOMMON.WRONG_MAPPING_CONFIG_MAPPING);
    }
    if (useStrict && (!docs || !docs.url)) {
        throw Error(message_1.MCOMMON.WRONG_DOCS_CONFIG);
    }
};
