"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const fs = require("fs");
const path = require("path");
const copy = require("recursive-copy");
const util = require("util");
const asyncExec = util.promisify(child_process_1.exec);
const asyncSpawn = util.promisify(child_process_1.spawn);
exports.default = {
    isEmptyDir(dir) {
        const files = fs.readdirSync(dir);
        return files.length === 0;
    },
    ensureRequire(path) {
        if (!fs.existsSync(path)) {
            throw Error(`${path} cannot be found, please check`);
        }
        // @ts-ignore
        delete require.cache[path];
        return require(path);
    },
    async asyncExec(cmd) {
        return asyncExec(cmd);
    },
    async asyncSpawn(cmd, args = [], options = {}) {
        return asyncSpawn(cmd, args, Object.assign({}, options, { stdio: 'inherit' }));
    },
    restoreFlags(flags) {
        const list = [];
        Object.keys(flags).forEach(key => {
            list.push(`--${key}`);
            if (typeof flags[key] !== 'boolean') {
                list.push(`${flags[key]}`);
            }
        });
        return list;
    },
    async copy(src, dest, mapping) {
        let option = Object.assign({ overwrite: true, dot: true }, mapping.option, { rename(filePath) {
                // fix rename problem if src type is file
                if (fs.lstatSync(src).isFile() && mapping.option.rename) {
                    const name = mapping.option.rename(path.basename(src));
                    return `../${name}`;
                }
                return filePath;
            } });
        await copy(src, dest, option);
    },
};
